@@ -20,7 +20,6 @@ from openstack import exceptions as sdk_exc
 from osc_lib.command import command
 from osc_lib import utils as oscutils
 from oslo_serialization import jsonutils
-from oslo_utils import uuidutils
 
 from cyborgclient.common import utils
 from cyborgclient import exceptions as exc
@@ -30,6 +29,20 @@ from cyborgclient.i18n import _
 class ListDeviceProfile(command.Lister):
     """List all device profiles"""
 
+    column_headers = (
+        "uuid",
+        "name",
+        "groups",
+        "description"
+    )
+    columns = (
+        "uuid",
+        "name",
+        "groups",
+        "description"
+    )
+    detail_cols = ("created_at", "updated_at")
+
     def get_parser(self, prog_name):
         parser = super(ListDeviceProfile, self).get_parser(prog_name)
         parser.add_argument(
@@ -43,41 +56,17 @@ class ListDeviceProfile(command.Lister):
 
     def take_action(self, parsed_args):
         acc_client = self.app.client_manager.accelerator
-
         if parsed_args.detail:
-            column_headers = (
-                "created_at",
-                "updated_at",
-                "uuid",
-                "name",
-                "groups"
-            )
-            columns = (
-                "created_at",
-                "updated_at",
-                "uuid",
-                "name",
-                "groups"
-            )
-        else:
-            column_headers = (
-                "uuid",
-                "name",
-                "groups",
-            )
-            columns = (
-                "uuid",
-                "name",
-                "groups",
-            )
+            self.column_headers += self.detail_cols
+            self.columns += self.detail_cols
 
         data = acc_client.device_profiles()
         if not data:
             return (), ()
         formatters = {}
-        return (column_headers,
+        return (self.column_headers,
                 (oscutils.get_item_properties(
-                    s, columns, formatters=formatters) for s in data))
+                    s, self.columns, formatters=formatters) for s in data))
 
 
 class CreateDeviceProfile(command.ShowOne):
@@ -158,8 +147,10 @@ class ShowDeviceProfile(command.ShowOne):
         parser = super(ShowDeviceProfile, self).get_parser(prog_name)
         parser.add_argument(
             "device_profile",
-            metavar="<uuid>",
-            help=_("UUID of the device_profile.")
+            metavar="<device_profile>",
+            help=_("Name or UUID of the device_profile."
+                   " The name field requires at least"
+                   " ``--os-accelerator-api-version 2.2``.")
         )
         return parser
 
@@ -170,11 +161,8 @@ class ShowDeviceProfile(command.ShowOne):
                                     parsed_args.device_profile)
 
 
-def _show_device_profile(acc_client, uuid):
+def _show_device_profile(acc_client, name_or_uuid):
     """Show detailed info about device_profile."""
-    if not uuidutils.is_uuid_like(uuid):
-        raise exc.CommandError(_('Only UUID of device_profile allowed. '
-                               'Invalid input: %s') % uuid)
 
     columns = (
         "created_at",
@@ -182,14 +170,16 @@ def _show_device_profile(acc_client, uuid):
         "uuid",
         "name",
         "groups",
+        "description",
     )
     try:
-        device_profile = acc_client.get_device_profile(uuid)
+        device_profile = acc_client.get_device_profile(name_or_uuid)
     except sdk_exc.ResourceNotFound:
-        raise exc.CommandError(_('device_profile not found: %s') % uuid)
-    formatters = {
-        'data': utils.json_formatter,
-    }
+        raise exc.CommandError(_('device_profile %s not found') % name_or_uuid)
+    except sdk_exc.HttpException as e:
+        raise exc.NotAcceptable(message=e.details)
+
+    formatters = {'data': utils.json_formatter}
     data = device_profile.to_dict()
     return columns, oscutils.get_dict_properties(data, columns,
                                                  formatters=formatters)
