@@ -12,6 +12,10 @@
 #
 import copy
 
+from openstack import exceptions as sdk_exc
+from osc_lib import utils as oscutils
+
+from cyborgclient.common import utils
 from cyborgclient import exceptions as exc
 from cyborgclient.osc.v2 import device_profile as osc_device_profile
 from cyborgclient.tests.unit.osc.v2 import fakes as acc_fakes
@@ -53,6 +57,7 @@ class TestDeviceProfileList(TestDeviceProfile):
             'uuid',
             'name',
             'groups',
+            'description'
         )
         self.assertEqual(collist, columns)
 
@@ -60,6 +65,7 @@ class TestDeviceProfileList(TestDeviceProfile):
             acc_fakes.device_profile_uuid,
             acc_fakes.device_profile_name,
             acc_fakes.device_profile_groups,
+            acc_fakes.device_profile_description,
         ), ]
         self.assertEqual(datalist, list(data))
 
@@ -72,21 +78,17 @@ class TestDeviceProfileList(TestDeviceProfile):
 
         self.mock_acc_client.device_profiles.assert_called_with(**kwargs)
 
-        collist = (
-            'created_at',
-            'updated_at',
-            'uuid',
-            'name',
-            'groups',
-        )
-        self.assertEqual(collist, columns)
+        collist = (osc_device_profile.ListDeviceProfile.columns +
+                   osc_device_profile.ListDeviceProfile.detail_cols)
+        self.assertEqual(list(collist), list(columns))
 
         datalist = [(
-            acc_fakes.device_profile_created_at,
-            acc_fakes.device_profile_updated_at,
             acc_fakes.device_profile_uuid,
             acc_fakes.device_profile_name,
             acc_fakes.device_profile_groups,
+            acc_fakes.device_profile_description,
+            acc_fakes.device_profile_created_at,
+            acc_fakes.device_profile_updated_at,
         ), ]
         self.assertEqual(datalist, list(data))
 
@@ -97,15 +99,43 @@ class TestDeviceProfileShow(TestDeviceProfile):
         super(TestDeviceProfileShow, self).setUp()
         self.cmd = osc_device_profile.ShowDeviceProfile(self.app, None)
 
-    def test_device_profile_show_with_name(self):
+    def test_device_profile_show_with_name_before_v22(self):
+        exc_msg = 'The minimal required API version should be 2.2'
+        self.mock_acc_client.get_device_profile.side_effect = \
+            sdk_exc.HttpException(details=exc_msg)
+
         arg_list = [acc_fakes.device_profile_name]
         verify_list = []
         parsed_args = self.check_parser(self.cmd, arg_list, verify_list)
-        result = self.assertRaises(exc.CommandError,
+        result = self.assertRaises(exc.NotAcceptable,
                                    self.cmd.take_action,
                                    parsed_args)
-        self.assertIn("Only UUID of device_profile allowed. "
-                      "Invalid input: fake_devprof_name", str(result))
+        self.assertIn(exc_msg, str(result))
+
+    def test_device_profile_show_with_name(self):
+        fake_dp = acc_fakes.FakeAcceleratorResource(
+            None,
+            copy.deepcopy(acc_fakes.DEVICE_PROFILE),
+            loaded=True)
+        self.mock_acc_client.get_device_profile.return_value = fake_dp
+
+        arg_list = [acc_fakes.device_profile_name]
+        verify_list = []
+        parsed_args = self.check_parser(self.cmd, arg_list, verify_list)
+        result = self.cmd.take_action(parsed_args)
+        columns = (
+            "created_at",
+            "updated_at",
+            "uuid",
+            "name",
+            "groups",
+            "description",
+        )
+        formatters = {'data': utils.json_formatter}
+        expected = oscutils.get_dict_properties(acc_fakes.DEVICE_PROFILE,
+                                                columns,
+                                                formatters=formatters)
+        self.assertEqual(result, (columns, expected))
 
 
 class TestDeviceProfileCreate(TestDeviceProfile):
@@ -136,6 +166,7 @@ class TestDeviceProfileCreate(TestDeviceProfile):
             'uuid',
             'name',
             'groups',
+            'description'
         )
         self.assertEqual(collist, columns)
 
@@ -145,5 +176,6 @@ class TestDeviceProfileCreate(TestDeviceProfile):
             acc_fakes.device_profile_uuid,
             acc_fakes.device_profile_name,
             acc_fakes.device_profile_groups,
+            acc_fakes.device_profile_description,
         ]
         self.assertEqual(datalist, list(data))
